%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

%if 0%{?rhel} && 0%{?rhel} >= 7
%global with_systemd 1
%global with_sysv 0
%endif

%if 0%{?rhel} && 0%{?rhel} < 7
%global with_systemd 0
%global with_sysv 1
%endif

Name:           mom
Version:        0.5.5
Release:        1%{?dist}
Summary:        Dynamically manage system resources on virtualization hosts

Group:          Applications/System
License:        GPLv2
URL:            http://wiki.github.com/aglitke/mom
Source0:        %{name}-%{version}.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:      noarch
BuildRequires:  python-devel
BuildRequires:  python-nose
BuildRequires:  automake
BuildRequires:  autoconf
%if 0%{?with_systemd}
BuildRequires:  systemd-units
%endif

# MOM makes use of libvirt by way of the python bindings to monitor and
# interact with virtual machines.
%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
Requires:       libvirt-daemon-driver-qemu
%else
Requires:       libvirt
%endif
Requires:       libvirt-python
Requires:       procps

%description
MOM is a policy-driven tool that can be used to manage overcommitment on KVM
hosts. Using libvirt, MOM keeps track of active virtual machines on a host. At
a regular collection interval, data is gathered about the host and guests. Data
can come from multiple sources (eg. the /proc interface, libvirt API calls, a
client program connected to a guest, etc). Once collected, the data is
organized for use by the policy evaluation engine. When started, MOM accepts a
user-supplied overcommitment policy. This policy is regularly evaluated using
the latest collected data. In response to certain conditions, the policy may
trigger reconfiguration of the system’s overcommitment mechanisms. Currently
MOM supports control of memory ballooning and KSM but the architecture is
designed to accommodate new mechanisms such as cgroups.



%prep
%setup -q

%build
autoreconf
%configure --docdir="%{_pkgdocdir}"
make %{?_smp_mflags}

%install
make DESTDIR="%{buildroot}" install

%if 0%{?with_sysv}
install -d -m 0755 "%{buildroot}/%{_initrddir}"
install -m 0755 contrib/momd.init "%{buildroot}/%{_initrddir}/momd"
%endif

%if 0%{?with_systemd}
install -dm 755 %{buildroot}%{_unitdir}
mv contrib/momd.service %{buildroot}%{_unitdir}
%endif

install -d -m 0755 "%{buildroot}/%{_sysconfdir}"
install -m 0644 doc/mom-balloon+ksm.conf "%{buildroot}/%{_sysconfdir}/momd.conf"

# Skip failing tests. Re-enable once fixed.
# %check
# nosetests tests/*.py

%if 0%{?with_sysv}
%preun
if [ $1 = 0 ] ; then
    /sbin/service momd stop >/dev/null 2>&1
    /sbin/chkconfig --del momd
fi

%postun
if [ "$1" -ge "1" ] ; then
    /sbin/service momd condrestart >/dev/null 2>&1 || :
fi
%endif

# Systemd scripts
%if 0%{?with_systemd}
%post
%systemd_post momd.service

%preun
%systemd_preun momd.service

%postun
%systemd_postun_with_restart momd.service
%endif

%files
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/momd.conf
%doc COPYING
%doc README
%{_sbindir}/momd
%{python_sitelib}/mom/

%if 0%{?with_systemd}
%{_unitdir}/momd.service
%endif

%if 0%{?with_sysv}
%{_initrddir}/momd
%endif

%changelog
* Mon Jun  27 2016 Martin Sivak <msivak@redhat.com> - 0.5.5-1
- Improve message when a VM disappears
  Resolves: rhbz#1234953
- Add GuestIoTuneOptional collector
  Resolves: rhbz#1346252

* Wed Jun  1 2016 Martin Sivak <msivak@redhat.com> - 0.5.4-1
- Rebase to the latest version
- Use i8 XML-RPC extension for transfering big numbers
  Resolves: rhbz#1294833
- Fix the momd.service file syntax
  Resolves: rhbz#1263983
- Lower the load disk QoS imposes on VDSM
  Resolves: rhbz#1337228
- Add GuestBalloonOptional collector
  Resolves: rhbz#1337834

* Thu Apr 07 2016 Martin Sivak <msivak@redhat.com> - 0.5.3-1
- Add support for disk QoS
  Resolves: rhbz#1324919

* Mon Jan 25 2016 Martin Sivak <msivak@redhat.com> - 0.5.2-1
- Fix xml-rpc issues with big numbers on machines with more
  than 2 TiB of RAM
  Resolves: rhbz#1302001

* Thu Sep 17 2015 Martin Sivak <msivak@redhat.com> - 0.5.1-1
- Fix vdsmxmlrpc hypervisor interface when no ballooning
  information is present.
  Resolves: rhbz#1264095

* Thu Jul 16 2015 Martin Sivak <msivak@redhat.com> - 0.5.0-1
- Rebased to new single threaded upstream version

* Thu Jun 11 2015 Martin Sivak <msivak@redhat.com> - 0.4.5-2
- Rebased to new upstream version

* Thu Nov 27 2014 Martin Sivak <msivak@redhat.com> - 0.4.1-4
- Use new CPU tune values even if only one of quota or period
  was changed.
  Related: rhbz#1143992

* Fri Nov 21 2014 Martin Sivak <msivak@redhat.com> - 0.4.1-3
- Make CPU policy work even when guest agent is not installed
  Resolves: rhbz#1143992

* Wed Nov 12 2014 Martin Sivak <msivak@redhat.com> - 0.4.1-2
- Fix vcpuLimit KeyError test blocker
  Resolves: rhbz#1163386

* Mon Feb 10 2014 Martin Sivak <msivak@redhat.com> - 0.4.1-1
- Rebase to match the upstream version that has basic
  CPU QoS support
  Related: rhbz#906927

* Mon Feb 10 2014 Martin Sivak <msivak@redhat.com> - 0.4.0-1
- Rebase to match the upstream version
  Resolves: rhbz#1064427

* Tue Nov 26 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-8
- Use new evaluator (with new variable stack) for each policy
  run.
  Resolves: rhbz#1025845

* Fri Nov 22 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-7
- Fix KeyError exception while qemu-guest-agent error handling
- communicate with qemu-guest-agent using hypervisor_iface via libvirt
- Add support for optional collector fields and (null expr) test
  Related: rhbz#1025845
- Add support for swap information to be used in policy
  Related: rhbz#1025845
- Make the policy language more lisp like
- Add tests to MANIFEST.in and run them during an rpm build
- Fix balloon policy syntax and semantics
  Resolves: rhbz#1025845
- Convert some keys of mem_stats in getVmMemoryStats()
- Start memory stats collection on initialization

* Thu Aug 22 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-6
- Fix ever increasing CPU usage
  Resolves: rhbz#999973

* Wed Aug 21 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-5
- Fix the changelog
  Related: rhbz#822623

* Wed Aug 21 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-4
- Include upstream fixes for KSM and libvirt
  Related: rhbz#967562

* Wed Jul 31 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-3
- Accept ballon info in string form
  Related: rhbz#974917

* Thu Jul 18 2013 Martin Sivak <msivak@redhat.com> - 0.3.2-1
- Update to keep the API in sync with VDSM
  Related: rhbz#822623

* Tue Jul 16 2013 Martin Sivak <msivak@redhat.com> - 0.3.1.1-1
- Upstream merged the patches we had
  Related: rhbz#822623

* Mon Jul 15 2013 Martin Sivak <msivak@redhat.com> - 0.3.1-1
- Initial package import
  Resolves: rhbz#822623
  Related: rhbz#967572
  Related: rhbz#967574
